@@ -3,7 +3,6 @@ from abc import ABCMeta
 from collections import defaultdict
 from typing import List, Dict
 
-from peek_plugin_base.PeekVortexUtil import peekServerName
 from twisted.internet.defer import DeferredList, inlineCallbacks, Deferred
 from vortex.DeferUtil import vortexLogFailure
 from vortex.Payload import Payload
@@ -40,20 +39,23 @@ class ACICacheHandlerABC(metaclass=ABCMeta):
             self._updateFromServerFilt, self._processObserve
         )
 
-        # Tell the logic service that this vortexUuid is interested in its data
-        VortexFactory.sendVortexMsg(
-            vortexMsgs=PayloadEnvelope(
-                filt=self._updateFromServerFilt
-            ).toVortexMsg(),
-            destVortexName=peekServerName,
-        )
-
         self._uuidsObserving = set()
 
     def shutdown(self):
         self._epObserve.shutdown()
         self._epObserve = None
 
+    def _filterOutOfflineVortexes(self):
+        # TODO, Change this to observe offline vortexes
+        # This depends on the VortexFactory offline observable implementation.
+        # Which is incomplete at this point :-|
+
+        vortexUuids = (
+            set(VortexFactory.getRemoteVortexUuids()) & self._uuidsObserving
+        )
+        self._uuidsObserving = vortexUuids
+
+
     # ---------------
     # Process update from the server
 
@@ -64,12 +66,14 @@ class ACICacheHandlerABC(metaclass=ABCMeta):
         from the server.
 
         """
-        vortexUuids = (
-            set(VortexFactory.getRemoteVortexUuids()) & self._uuidsObserving
-        )
-        self._uuidsObserving = vortexUuids
+        self._filterOutOfflineVortexes()
 
-        payloadsByVortexUuid = defaultdict(Payload)
+        def cratePayloadEnvelope():
+            payloadEnvelope = PayloadEnvelope()
+            payloadEnvelope.data = []
+            return payloadEnvelope
+
+        payloadsByVortexUuid = defaultdict(cratePayloadEnvelope)
 
         for chunkKey in chunkKeys:
             encodedChunkedIndexChunk = self._cacheController.encodedChunk(
@@ -77,26 +81,23 @@ class ACICacheHandlerABC(metaclass=ABCMeta):
             )
 
             # Queue up the required client notifications
-            for vortexUuid in vortexUuids:
+            for vortexUuid in self._uuidsObserving:
                 self._logger.debug(
                     "Sending unsolicited chunkedIndex %s to vortex %s",
                     chunkKey,
                     vortexUuid,
                 )
-                payloadsByVortexUuid[vortexUuid].tuples.append(
+                payloadsByVortexUuid[vortexUuid].data.append(
                     encodedChunkedIndexChunk
                 )
 
         # Send the updates to the clients
         dl = []
-        for vortexUuid, payload in list(payloadsByVortexUuid.items()):
+        for vortexUuid, payloadEnvelope in list(payloadsByVortexUuid.items()):
             payload.filt = self._updateFromServerFilt
 
             # Serialise in thread, and then send.
-            d = payload.makePayloadEnvelopeDefer()
-            d.addCallback(
-                lambda payloadEnvelope: payloadEnvelope.toVortexMsgDefer()
-            )
+            d = payloadEnvelope.toVortexMsgDefer(base64Encode=False)
             d.addCallback(
                 VortexFactory.sendVortexMsg, destVortexUuid=vortexUuid
             )
